# Generated by Django 2.0.2 on 2018-02-13 15:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('slackchat', '0001_squashed_0010_auto_20180210_1726'),
    ]

    operations = [
        migrations.AddField(
            model_name='channel',
            name='team_id',
            field=models.SlugField(blank=True, editable=False, help_text='Slack API team ID', max_length=10, null=True),
        ),
        migrations.AlterField(
            model_name='channel',
            name='api_id',
            field=models.SlugField(blank=True, editable=False, help_text='Slack API channel ID', max_length=10, null=True),
        ),
    ]
