# Generated by Django 2.0.2 on 2018-03-17 01:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('slackchat', '0003_auto_20180317_0028'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='channel',
            name='image',
        ),
        migrations.RemoveField(
            model_name='channel',
            name='meta_keywords',
        ),
        migrations.AddField(
            model_name='channel',
            name='meta_image',
            field=models.URLField(blank=True, help_text='Share image URL', null=True),
        ),
        migrations.AlterField(
            model_name='channel',
            name='meta_description',
            field=models.CharField(blank=True, help_text='Page description', max_length=300, null=True),
        ),
        migrations.AlterField(
            model_name='channel',
            name='meta_title',
            field=models.CharField(blank=True, help_text='Page title', max_length=300, null=True),
        ),
    ]
