# Generated by Django 2.0.2 on 2018-03-17 00:28

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('slackchat', '0002_auto_20180213_1510'),
    ]

    operations = [
        migrations.AlterField(
            model_name='channel',
            name='owner',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='slackchat.User'),
        ),
    ]
