# Generated by Django 2.0.2 on 2018-03-17 02:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('slackchat', '0004_auto_20180317_0126'),
    ]

    operations = [
        migrations.AddField(
            model_name='chattype',
            name='publish_prefix',
            field=models.CharField(default='/slackchats/', help_text="A relative prefix that a renderer may append to a publish path when         publishing the slackchat, e.g.,         <span style='color:grey; font-weight:bold;'>/slackchats/        </span>.", max_length=300),
        ),
    ]
