# Generated by Django 2.0.2 on 2018-03-17 23:28

from django.db import migrations, models
import django.utils.timezone
import slackchat.fields


class Migration(migrations.Migration):

    dependencies = [
        ('slackchat', '0005_chattype_publish_prefix'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='chattype',
            name='publish_prefix',
        ),
        migrations.AddField(
            model_name='chattype',
            name='publish_path',
            field=models.CharField(default='/slackchats/', help_text="A relative path for the slackchat type         you can append to any slackchat channel's         publish path, e.g.,         <span style='color:grey; font-weight:bold;'>/slackchats/        </span>.", max_length=300),
        ),
        migrations.AlterField(
            model_name='channel',
            name='introduction',
            field=slackchat.fields.MarkdownField(blank=True, help_text='Some introductory paragraph text (in markdown syntax).', null=True),
        ),
        migrations.AlterField(
            model_name='channel',
            name='live',
            field=models.BooleanField(default=False, help_text='Determines whether page should re-poll for new messages         while chat is live.'),
        ),
        migrations.AlterField(
            model_name='channel',
            name='publish_path',
            field=models.CharField(blank=True, help_text="A relative path you can use when         publishing the slackchat, e.g.,         <span style='color:grey; font-weight:bold;'>/2018-02-12/econ-chat/        </span>.", max_length=300, unique=True),
        ),
        migrations.AlterField(
            model_name='channel',
            name='publish_time',
            field=models.DateTimeField(default=django.utils.timezone.now, help_text='Dateline.'),
        ),
    ]
