# Generated by Django 2.0.2 on 2018-03-18 15:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('slackchat', '0006_auto_20180317_2328'),
    ]

    operations = [
        migrations.AlterField(
            model_name='chattype',
            name='name',
            field=models.SlugField(max_length=255),
        ),
    ]
